********************
Introduction to PyQn
********************



PyQn is a Python package for parsing, validating, manipulating and
transforming physical quantities and their units.

Units are specified as strings using a simple and flexible syntax,
and may be compared, output in different formats and manipulated using a
variety of predefined Python methods.
